## 介绍 ![](https://img.shields.io/badge/Python-3.7-green.svg)

    学习Python的集合包.有利于重复使用,避免重复造轮子.并且还能温故而知新.里面包括了许多模块,其中包括:搜狗词库下载,新词发现算法,
    照片和PDF相互转化, 微信自动聊天机器人,中国农历与阳历的转换关系,简体字与繁体字的转换,坦克小游戏,分形模式,邮箱,地图,正则,装饰器,
    数学统计,数据处理,nlp算法、进制转换 验证码识别 数据下载 分形模型 小游戏 照片与PDF互转 语言处理 邮箱应用 阳历转农历 搜狗下载 
    网页处理 新词发现 微信 正则 装饰器 异常 地图 计算统计 贝叶斯算法 常见的工具类 c模块 百度应用 日语单词翻译、天气预报、汉语纠错、反射等等
  
## 安装
    pip install jtyoui
    
    
## 支持版本
    python 3.x

________________________

## 模块如下

01. [任意进制转换](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/bs)  
02. [验证码识别](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/code)  
03. [数据下载](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/data)  
04. [分形模型](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/fractal)   
05. [小游戏 ](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/game)  
06. [照片与PDF互转](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/imagepdf)   
07. [语言处理 ](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/language)   
08. [邮箱应用 ](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/mail)
09. [阳历和农历相互转换](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/plunar) 
10. [搜狗下载](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/sogou)   
11. [网页处理](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/web)  
12. [新词发现](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/word)    
13. [微信](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/wx)    
14. [正则](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/regular)   
15. [装饰器](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/decorator)
16. [异常](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/error)        
17. [地图](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/maps)
18. [计算统计](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/statistics)  
19. [贝叶斯算法](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/bayes)  
20. [常见的工具类](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/tools) 
21. [c模块](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/c)    
22. [百度应用](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/baidu)   
23. [日语单词翻译](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/jp)    
24. [压缩包工具](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/compress)   
25. [常用算法](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/algorithm)   
26. [CMD命令](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/cmd)  
27. [自然语言处理](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/neuralNetwork)  
28. [反射模块](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/reflex)   
29. [日志模块](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/logger)   
30. [项目接口文件](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/project)   
31. [中国人属性包](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/person)   
31. [口语化时间处理](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/time)   
32. [机器学习模型](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/ml)  
33. [爬虫模块](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/reptile)            
34. [实体抽取](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/ee)    
35. [flask框架模块](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/flasks)  

__________________________


## introduce
    Learning Python's collection package is conducive to reuse and avoid repeating wheel building. It can also learn new things from the past. It includes many modules, including: Sogou Lexicon Download, New Word Discovery Algorithms,
    Photos and PDF transform each other, Wechat Auto Chat Robot, Chinese Lunar Calendar and solar calendar conversion relationship, simplified and traditional characters conversion, tank games, fractal mode, mailbox, map, regular, decorator,
    Mathematical statistics, data processing, NLP algorithm, binary conversion validation code identification data download fractal model small game photos and PDF language processing mailbox application calendar to lunar search dog Download
    Web page processing new words discovery Weixin regular decorator abnormal map calculation statistics Bayesian algorithm common tool class C module Baidu uses Japanese word translation, weather forecast, Chinese error correction, reflection and so on
